@@ -628,6 +628,9 @@ SERVICE_VERSIONS = {
     "tcss": [
         "2020-11-01"
     ],
+    "tdai": [
+        "2025-07-17"
+    ],
     "tdcpg": [
         "2021-11-18"
     ],
@@ -754,7 +757,8 @@ SERVICE_VERSIONS = {
         "2021-01-29"
     ],
     "wedata": [
-        "2021-08-20"
+        "2021-08-20",
+        "2025-08-06"
     ],
     "weilingwith": [
         "2023-04-27"
